==> httpdbg-0.10.1.tar.gz: httpdbg-0.10.1/httpdbg/hooks/urllib3.py <==
# -*- coding: utf-8 -*-
from contextlib import contextmanager
import traceback

from httpdbg.hooks.utils import getcallargs
from httpdbg.hooks.utils import decorate
from httpdbg.hooks.utils import undecorate
from httpdbg.initiator import httpdbg_initiator
from httpdbg.records import HTTPRecord


def set_hook_for_urllib3(records, method):
    def hook(*args, **kwargs):
        initiator = None
        try:
            with httpdbg_initiator(
                records, traceback.extract_stack(), method, *args, **kwargs
            ) as initiator:
                ret = method(*args, **kwargs)
            return ret
        except Exception as ex:
            callargs = getcallargs(method, *args, **kwargs)

            if "url" in callargs:
                if initiator:
                    record = HTTPRecord()

                    record.initiator = initiator
                    record.url = str(callargs["url"])
                    record.exception = ex

                    records.requests[record.id] = record
            raise

    return hook


@contextmanager
def hook_urllib3(records):
    hooks = False
    try:
        import urllib3

        urllib3.PoolManager.request = decorate(
            records, urllib3.PoolManager.request, set_hook_for_urllib3
        )
        urllib3.HTTPConnectionPool.request = decorate(
            records, urllib3.HTTPConnectionPool.request, set_hook_for_urllib3
        )

        hooks = True
    except ImportError:
        pass

    yield

    if hooks:
        urllib3.PoolManager.request = undecorate(urllib3.PoolManager.request)
        urllib3.HTTPConnectionPool.request = undecorate(
            urllib3.HTTPConnectionPool.request
        )

==> httpdbg-0.11.5.tar.gz: httpdbg-0.11.5/httpdbg/hooks/urllib3.py <==
# -*- coding: utf-8 -*-
from contextlib import contextmanager
import traceback
from typing import Generator

from httpdbg.hooks.utils import getcallargs
from httpdbg.hooks.utils import decorate
from httpdbg.hooks.utils import undecorate
from httpdbg.initiator import httpdbg_initiator
from httpdbg.records import HTTPRecord
from httpdbg.records import HTTPRecords


def set_hook_for_urllib3(records, method):
    def hook(*args, **kwargs):
        initiator = None
        try:
            with httpdbg_initiator(
                records, traceback.extract_stack(), method, *args, **kwargs
            ) as initiator:
                ret = method(*args, **kwargs)
            return ret
        except Exception as ex:
            callargs = getcallargs(method, *args, **kwargs)

            if "url" in callargs:
                if initiator:
                    record = HTTPRecord()

                    record.initiator = initiator
                    record.url = str(callargs["url"])
                    record.exception = ex

                    records.requests[record.id] = record
            raise

    return hook


@contextmanager
def hook_urllib3(records: HTTPRecords) -> Generator[None, None, None]:
    hooks = False
    try:
        import urllib3

        urllib3.PoolManager.request = decorate(
            records, urllib3.PoolManager.request, set_hook_for_urllib3
        )
        urllib3.HTTPConnectionPool.request = decorate(
            records, urllib3.HTTPConnectionPool.request, set_hook_for_urllib3
        )

        hooks = True
    except ImportError:
        pass

    yield

    if hooks:
        urllib3.PoolManager.request = undecorate(urllib3.PoolManager.request)
        urllib3.HTTPConnectionPool.request = undecorate(
            urllib3.HTTPConnectionPool.request
        )
